@@ -8,7 +8,7 @@ package Sumu::Perl::Modules;
 
 =head1 VERSION
 
-version 0.4.6
+version 0.4.7
 
 =head2 SYNOPSIS
 
@@ -73,13 +73,13 @@ use warnings;
 
 =head2 our VERSION
 
-    our $VERSION = '0.4.6'
+    our $VERSION = '0.4.7'
 
     This version number is updated automatically!
 
 =cut
 
-our $VERSION = '0.4.6';
+our $VERSION = '0.4.7';
 
 
 =head2 Internals
@@ -415,10 +415,10 @@ sub _inc_dir {
 	my $out;
 	$out .= qq{};
 
-	my @directoreis;
+	my @directories;
 	my @files;
 
-	my $dir = $in{inc_dir};
+	my $dir = "$in{inc_dir}";
 	chomp $dir;
 
 	if (-d "$dir") {
@@ -428,16 +428,16 @@ sub _inc_dir {
 			#
 			while ( my $item = <@dir> ) {
 				#Directories
-				push(@directoreis, "$dir/$item") if (-d "$dir/$item");
+				push(@directories, "$dir/$item") if (-d "$dir/$item");
 				# Files
 				push(@files, "$dir/$item") if (-f "$dir/$item");
 			}
 			#
 		} else {
-			$out = qq{Unable to open dir};
+			$out = qq{<div class="alert alert-warning">Unable to open dir</div>};
 		}
 	} else {
-		$out = qq{Not a Dir};
+		$out = qq{<div class="alert alert-warning">Not a Dir $dir</div>};
 	}
 	#
 
@@ -451,7 +451,7 @@ sub _inc_dir {
 
 	#
 	$out .= qq{<article class="container"><h2>Directories</h2>};
-	for (@directoreis) {
+	for (@directories) {
 		#
 		my @d_name = split(/\//, $_);
 		$out .= qq{<a href="/_inc/$_" title="$d_name[$#d_name]">$d_name[$#d_name]</a> };
